@@ -1,8 +1,11 @@
 /* vim:set ft=c ts=4 sw=4 et fdm=marker: */
 
+#ifndef DDEBUG
 #define DDEBUG 0
+#endif
 #include "ddebug.h"
 
+#include <nginx.h>
 #include <ngx_md5.h>
 #include "ngx_http_lua_common.h"
 #include "ngx_http_lua_cache.h"
@@ -13,7 +16,6 @@
 static void ngx_http_lua_clear_package_loaded(lua_State *L);
 
 
-
 /**
  * Find code chunk associated with the given key in code cache,
  * and push it to the top of Lua stack if found.
@@ -27,7 +29,7 @@ static void ngx_http_lua_clear_package_loaded(lua_State *L);
  *
  * */
 static ngx_int_t
-ngx_http_lua_cache_load_code(lua_State *L, const char *ck)
+ngx_http_lua_cache_load_code(lua_State *L, const char *key)
 {
     /*  get code cache table */
     lua_getfield(L, LUA_REGISTRYINDEX, LUA_CODE_CACHE_KEY);    /*  sp++ */
@@ -39,7 +41,7 @@ ngx_http_lua_cache_load_code(lua_State *L, const char *ck)
         return NGX_ERROR;
     }
 
-    lua_getfield(L, -1, ck);    /*  sp++ */
+    lua_getfield(L, -1, key);    /*  sp++ */
 
     if (lua_isfunction(L, -1)) {
         /*  call closure factory to gen new closure */
@@ -78,12 +80,12 @@ ngx_http_lua_cache_load_code(lua_State *L, const char *ck)
  *
  * */
 static ngx_int_t
-ngx_http_lua_cache_store_code(lua_State *L, const char *ck)
+ngx_http_lua_cache_store_code(lua_State *L, const char *key)
 {
     int rc;
 
     /*  get code cache table */
-    lua_getfield(L, LUA_REGISTRYINDEX, LUA_CODE_CACHE_KEY);    /*  sp++ */
+    lua_getfield(L, LUA_REGISTRYINDEX, LUA_CODE_CACHE_KEY); /* closure cache */
 
     dd("Code cache table to store: %p", lua_topointer(L, -1));
 
@@ -92,11 +94,11 @@ ngx_http_lua_cache_store_code(lua_State *L, const char *ck)
         return NGX_ERROR;
     }
 
-    lua_pushvalue(L, -2);        /*  sp++ */
-    lua_setfield(L, -2, ck);    /*  sp-- */
+    lua_pushvalue(L, -2); /* closure cache closure */
+    lua_setfield(L, -2, key); /* closure cache */
 
     /*  remove cache table, leave closure factory at top of stack */
-    lua_pop(L, 1);                /*  sp-- */
+    lua_pop(L, 1); /* closure */
 
     /*  call closure factory to generate new closure */
     rc = lua_pcall(L, 0, 1, 0);
@@ -112,7 +114,7 @@ ngx_http_lua_cache_store_code(lua_State *L, const char *ck)
 ngx_int_t
 ngx_http_lua_cache_loadbuffer(lua_State *L, const u_char *src, size_t src_len,
         const u_char *cache_key, const char *name, char **err,
-        ngx_flag_t enabled)
+        unsigned enabled)
 {
     int          rc;
 
@@ -168,7 +170,7 @@ ngx_http_lua_cache_loadbuffer(lua_State *L, const u_char *src, size_t src_len,
 
 ngx_int_t
 ngx_http_lua_cache_loadfile(lua_State *L, const u_char *script,
-        const u_char *cache_key, char **err, ngx_flag_t enabled)
+        const u_char *cache_key, char **err, unsigned enabled)
 {
     int              rc;
 
@@ -267,6 +269,16 @@ ngx_http_lua_clear_package_loaded(lua_State *L)
 
         p = (u_char *) lua_tolstring(L, -1, &len);
 
+#if 1
+        /* XXX work-around the "stack overflow" issue of LuaRocks
+         * while unloading and reloading Lua modules */
+        if (len >= sizeof("luarocks") - 1 &&
+                ngx_strncmp(p, "luarocks", sizeof("luarocks") - 1) == 0)
+        {
+            goto done;
+        }
+#endif
+
         switch (len) {
         case 2:
             if (ngx_strncmp(p, "os", sizeof("os") - 1) == 0) {
@@ -292,6 +304,14 @@ ngx_http_lua_clear_package_loaded(lua_State *L)
                 goto done;
             }
 
+            if (ngx_strncmp(p, "ngx", sizeof("ngx") - 1) == 0) {
+                goto done;
+            }
+
+            if (ngx_strncmp(p, "ndk", sizeof("ndk") - 1) == 0) {
+                goto done;
+            }
+
             break;
 
         case 4:
