@@ -1,11 +1,13 @@
 /* vim:set ft=c ts=4 sw=4 et fdm=marker: */
 
+#ifndef DDEBUG
 #define DDEBUG 0
+#endif
 
-#include "nginx.h"
+#include <nginx.h>
 #include "ngx_http_lua_contentby.h"
 #include "ngx_http_lua_util.h"
-#include "ngx_http_lua_hook.h"
+#include "ngx_http_lua_exception.h"
 #include "ngx_http_lua_cache.h"
 
 
@@ -33,6 +35,7 @@ ngx_http_lua_content_by_chunk(lua_State *L, ngx_http_request_t *r)
         dd("setting new ctx, ctx = %p", ctx);
 
         ctx->cc_ref = LUA_NOREF;
+        ctx->ctx_ref = LUA_NOREF;
 
         ngx_http_set_ctx(r, ctx, ngx_http_lua_module);
 
@@ -124,6 +127,7 @@ ngx_http_lua_content_handler(ngx_http_request_t *r)
         dd("setting new ctx: ctx = %p", ctx);
 
         ctx->cc_ref = LUA_NOREF;
+        ctx->ctx_ref = LUA_NOREF;
 
         ngx_http_set_ctx(r, ctx, ngx_http_lua_module);
     }
@@ -141,10 +145,11 @@ ngx_http_lua_content_handler(ngx_http_request_t *r)
         return rc;
     }
 
-    if (llcf->force_read_body &&
-            ! ctx->read_body_done &&
-            ((r->method & NGX_HTTP_POST) || (r->method & NGX_HTTP_PUT)))
-    {
+    if (llcf->force_read_body && !ctx->read_body_done) {
+        r->request_body_in_single_buf = 1;
+        r->request_body_in_persistent_file = 1;
+        r->request_body_in_clean_file = 1;
+
         rc = ngx_http_read_client_request_body(r,
                 ngx_http_lua_content_phase_post_read);
 
@@ -174,8 +179,6 @@ ngx_http_lua_content_phase_post_read(ngx_http_request_t *r)
 {
     ngx_http_lua_ctx_t  *ctx;
 
-    r->read_event_handler = ngx_http_request_empty_handler;
-
     ctx = ngx_http_get_module_ctx(r, ngx_http_lua_module);
 
     ctx->read_body_done = 1;
@@ -221,7 +224,7 @@ ngx_http_lua_content_handler_file(ngx_http_request_t *r)
 
     /*  load Lua script file (w/ cache)        sp = 1 */
     rc = ngx_http_lua_cache_loadfile(L, script_path, llcf->content_src_key,
-            &err, llcf->enable_code_cache);
+            &err, llcf->enable_code_cache ? 1 : 0);
 
     if (rc != NGX_OK) {
         if (err == NULL) {
@@ -275,7 +278,7 @@ ngx_http_lua_content_handler_inline(ngx_http_request_t *r)
     /*  load Lua inline script (w/ cache) sp = 1 */
     rc = ngx_http_lua_cache_loadbuffer(L, llcf->content_src.value.data,
             llcf->content_src.value.len, llcf->content_src_key,
-            "content_by_lua", &err, llcf->enable_code_cache);
+            "content_by_lua", &err, llcf->enable_code_cache ? 1 : 0);
 
     if (rc != NGX_OK) {
         if (err == NULL) {
